# Cloud Resources
A package for handling your cloud infrastructure resources

##Introduction

This python library handles operations on your cloud infrastructure. By using this library, you can make your code independent of the underlaying cloud service provider SDK and it's implementation.

Currently, this package supports AWS only.

This project provides the following functionality:

- Catalysts for CDN, Cluster & autoscaling, NoSQL DB, Cloud based queue and storage
- Fetching resources from your cloud infrastructure
- Regional resource support
- Error handling & automatic Sentry logging

## Getting Started

This library consists of multiple catalyst modules, providing functionalities ranging from storage handling and autoscaling.

In your core code, you can import any catalyst and utilize resource functionalities. For example, to fetch any object from your cloud storage (S3), you can do something like:

```
from cloud_resources import storage_catalyst

def some_getter(object_name):
    cloud_object = storage_catalyst.get_object(object_name, 'my-bucket')
    ....
...
```

Similarly, to create a partition (Bucket) and write objects, you can use:

```
from cloud_resources import storage_catalyst

def some_creator(serial_object):
    storage_catalyst.create_partition('my-bucket')
    storage_catalyst.write_object('my-key/', serial_object, 'my-bucket')
    ....
...

```

The catalyst modules are extensively documented. You can pick up any catalyst module you would like, based on your infrastructure requirement and just call the respective function.

### Prerequisites

Elucidata's privately maintained pip server should be configured properly to
install via pip. Also, you need to be on the Elucidata's static IP for this to work.

In ~/.pip/pip.conf on Mac/Linux, add:

```
[global]
extra-index-url = http://54.245.179.143/
[install]
trusted-host=54.245.179.143
```

 - In order to use CloudFront signing, you need to setup ```SIGNING_PEM_FILE_PATH``` environment variable to the full file path of the ```.pem``` file for signing.
 - In order to use Dynamo DB, you need to setup following environment variables:

    ```
    DYNAMO_ACCESS_KEY=<AccessKey>
    DYNAMO_SECRET_KEY=<SecretKey>
    DYNAMO_REGION=<DeploymentRegion>
    ```

### Installing

Clone the repository or install using pip:

```
pip install --upgrade cloud_resources
```

## Deployment

Just install cloud_resources as pip/python dependency on your code layer, after utilizing the catalysts.

## Built With

* [Boto3](https://boto3.readthedocs.io) - AWS SDK for python
* [Sentry](https://sentry.io) - Real time error tracking.
* Love

## Versioning

We use [SemVer](http://semver.org/) for versioning.

## Contributors
Pulkit Kumar - pulkit.kumar@elucidata.io

## License

This project is developed and maintained internally by Elucidata Inc.
